@@ -41,6 +41,9 @@ public class DefaultClassPathProvider implements ClassPathProvider {
         if (name.equals("GRADLE_BASE_SERVICES")) {
             return moduleRegistry.getModule("gradle-base-services").getImplementationClasspath();
         }
+        if (name.equals("GRADLE_INSTALLATION_BEACON")) {
+            return moduleRegistry.getModule("gradle-installation-beacon").getImplementationClasspath();
+        }
         if (name.equals("COMMONS_CLI")) {
             return moduleRegistry.getExternalModule("commons-cli").getClasspath();
         }
