@@ -595,7 +595,7 @@ public class AnnotationProcessingTaskFactoryTest {
     }
 
     @Test
-    @Issue("https://issues.gradle.org/browse/GRADLE-2815")
+    @Issue("https://issues.gradle.org/Browse/GRADLE-2815")
     public void registersSpecifiedBooleanInputValue() {
         TaskWithBooleanInput task = expectTaskCreated(TaskWithBooleanInput.class, true);
         assertThat(task.getInputs().getProperties().get("inputValue"), equalTo((Object) true));
@@ -707,6 +707,42 @@ public class AnnotationProcessingTaskFactoryTest {
         assertThat(task.isHasCustomActions(), equalTo(false));
     }
 
+    @Test
+    public void ignoresBridgeMethods() {
+        TaskWithBridgeMethod task = expectTaskCreated(TaskWithBridgeMethod.class);
+        task.getOutputs().getFiles().getFiles();
+        assertThat(task.traversedOutputsCount, is(1));
+    }
+
+    @Test
+    public void propertyExtractionJavaBeanSpec() {
+        TaskWithJavaBeanCornerCaseProperties task = expectTaskCreated(TaskWithJavaBeanCornerCaseProperties.class, "c", "C", "d", "U", "a", "b");
+        assertThat("cCompiler property", task.getInputs().getProperties().get("cCompiler"), notNullValue());
+        assertThat("CFlags property", task.getInputs().getProperties().get("CFlags"), notNullValue());
+        assertThat("dns property", task.getInputs().getProperties().get("dns"), notNullValue());
+        assertThat("URL property", task.getInputs().getProperties().get("URL"), notNullValue());
+        assertThat("a property", task.getInputs().getProperties().get("a"), notNullValue());
+        assertThat("b property", task.getInputs().getProperties().get("b"), notNullValue());
+    }
+
+    @Test
+    public void propertyValidationJavaBeanSpecCase() {
+        TaskWithJavaBeanCornerCaseProperties task = expectTaskCreated(TaskWithJavaBeanCornerCaseProperties.class, new Object[]{null, null, null, null, "a", "b"});
+        assertValidationFails(task,
+            "No value has been specified for property 'cCompiler'.",
+            "No value has been specified for property 'CFlags'.",
+            "No value has been specified for property 'dns'.",
+            "No value has been specified for property 'URL'.");
+    }
+
+    @Test
+    public void propertyValidationJavaBeanSpecSingleChar() {
+        TaskWithJavaBeanCornerCaseProperties task = expectTaskCreated(TaskWithJavaBeanCornerCaseProperties.class, new Object[]{"c", "C", "d", "U", null, null});
+        assertValidationFails(task,
+            "No value has been specified for property 'a'.",
+            "No value has been specified for property 'b'.");
+    }
+
     private void assertValidationFails(TaskInternal task, String... expectedErrorMessages) {
         try {
             task.execute();
@@ -947,6 +983,31 @@ public class AnnotationProcessingTaskFactoryTest {
         }
     }
 
+    public static class TaskWithBridgeMethod extends DefaultTask implements WithProperty<SpecificProperty> {
+        @org.gradle.api.tasks.Nested
+        private SpecificProperty nestedProperty = new SpecificProperty();
+        public int traversedOutputsCount;
+
+        public SpecificProperty getNestedProperty() {
+            traversedOutputsCount++;
+            return nestedProperty;
+        }
+    }
+
+    public interface WithProperty<T extends PropertyContainer> {
+        T getNestedProperty();
+    }
+    public interface PropertyContainer<T extends SomeProperty> {}
+    public static class SpecificProperty extends SomePropertyContainer<SomeProperty> {}
+    public static class SomeProperty {}
+
+    public static abstract class SomePropertyContainer<T extends SomeProperty> implements PropertyContainer {
+        @OutputDirectories
+        public Set<File> getSomeOutputFiles() {
+            return Collections.emptySet();
+        }
+    }
+
     public static class TaskWithOptionalOutputFile extends DefaultTask {
         @OutputFile
         @org.gradle.api.tasks.Optional
@@ -1117,4 +1178,54 @@ public class AnnotationProcessingTaskFactoryTest {
             return inputFile2;
         }
     }
+
+    //CHECKSTYLE:OFF
+    public static class TaskWithJavaBeanCornerCaseProperties extends DefaultTask {
+        private String cCompiler;
+        private String CFlags;
+        private String dns;
+        private String URL;
+        private String a;
+        private String b;
+
+        public TaskWithJavaBeanCornerCaseProperties(String cCompiler, String CFlags, String dns, String URL, String a, String b) {
+            this.cCompiler = cCompiler;
+            this.CFlags = CFlags;
+            this.dns = dns;
+            this.URL = URL;
+            this.a = a;
+            this.b = b;
+        }
+
+        @Input
+        public String getcCompiler() {
+            return cCompiler;
+        }
+
+        @Input
+        public String getCFlags() {
+            return CFlags;
+        }
+
+        @Input
+        public String getDns() {
+            return dns;
+        }
+
+        @Input
+        public String getURL() {
+            return URL;
+        }
+
+        @Input
+        public String getA() {
+            return a;
+        }
+
+        @Input
+        public String getb() {
+            return b;
+        }
+    }
+    //CHECKSTYLE:ON
 }
