@@ -36,6 +36,7 @@ import java.util.jar.JarFile;
 import java.util.jar.Manifest;
 
 import static org.junit.Assert.*;
+import static org.junit.Assume.assumeTrue;
 
 public class TestFile extends File {
     private boolean useNativeTools;
@@ -272,6 +273,15 @@ public class TestFile extends File {
         return this;
     }
 
+    /**
+     * Changes the last modified time for this file so that it is different to and smaller than its current last modified time, within file system resolution.
+     */
+    public TestFile makeOlder() {
+        // Just move back 2 seconds
+        setLastModified(lastModified() - 2000L);
+        return this;
+    }
+
     /**
      * Creates a directory structure specified by the given closure.
      * <pre>
@@ -318,7 +328,11 @@ public class TestFile extends File {
     }
 
     public TestFile assertIsDir() {
-        assertTrue(String.format("%s is not a directory", this), isDirectory());
+        return assertIsDir("");
+    }
+
+    public TestFile assertIsDir(String hint) {
+        assertTrue(String.format("%s is not a directory. %s", this, hint), isDirectory());
         return this;
     }
 
@@ -437,6 +451,14 @@ public class TestFile extends File {
         return this;
     }
 
+    public Set<String> allDescendants() {
+        Set<String> names = new TreeSet<String>();
+        if (isDirectory()) {
+            visit(names, "", this);
+        }
+        return names;
+    }
+
     private void visit(Set<String> names, String prefix, File file) {
         for (File child : file.listFiles()) {
             if (child.isFile()) {
@@ -549,6 +571,16 @@ public class TestFile extends File {
         return this;
     }
 
+    public TestFile bzip2To(TestFile compressedFile) {
+        new TestFileHelper(this).bzip2To(compressedFile);
+        return this;
+    }
+
+    public TestFile gzipTo(TestFile compressedFile) {
+        new TestFileHelper(this).gzipTo(compressedFile);
+        return this;
+    }
+
     public Snapshot snapshot() {
         assertIsFile();
         return new Snapshot(lastModified(), getHash("MD5"));
@@ -590,6 +622,10 @@ public class TestFile extends File {
         }
     }
 
+    public void assumeExists() {
+        assumeTrue(this.exists());
+    }
+
     public ExecOutput exec(Object... args) {
         return new TestFileHelper(this).execute(Arrays.asList(args), null);
     }
