@@ -54,8 +54,8 @@ public class IncrementalCompilerDecorator {
         this.sourceDirs = sourceDirs;
     }
 
-    public Compiler<JavaCompileSpec> prepareCompiler(final IncrementalTaskInputs inputs) {
-        final Compiler<JavaCompileSpec> compiler = getCompiler(inputs, sourceDirs);
+    public Compiler<JavaCompileSpec> prepareCompiler(IncrementalTaskInputs inputs) {
+        Compiler<JavaCompileSpec> compiler = getCompiler(inputs, sourceDirs);
         return new IncrementalCompilationFinalizer(compiler, jarClasspathSnapshotMaker, classSetAnalysisUpdater);
     }
 
