@@ -18,7 +18,6 @@ package org.gradle.play.internal.toolchain;
 
 import org.gradle.api.internal.file.FileResolver;
 import org.gradle.api.internal.tasks.compile.daemon.CompilerDaemonManager;
-import org.gradle.internal.Factory;
 import org.gradle.language.base.internal.compile.CompileSpec;
 import org.gradle.language.base.internal.compile.Compiler;
 import org.gradle.play.internal.javascript.GoogleClosureCompiler;
@@ -27,13 +26,14 @@ import org.gradle.play.internal.platform.PlayMajorVersion;
 import org.gradle.play.internal.routes.RoutesCompileSpec;
 import org.gradle.play.internal.routes.RoutesCompiler;
 import org.gradle.play.internal.routes.RoutesCompilerFactory;
-import org.gradle.play.internal.run.*;
+import org.gradle.play.internal.run.PlayApplicationRunner;
+import org.gradle.play.internal.run.PlayApplicationRunnerFactory;
 import org.gradle.play.internal.spec.PlayCompileSpec;
 import org.gradle.play.internal.twirl.TwirlCompileSpec;
 import org.gradle.play.internal.twirl.TwirlCompiler;
 import org.gradle.play.internal.twirl.TwirlCompilerFactory;
 import org.gradle.play.platform.PlayPlatform;
-import org.gradle.process.internal.WorkerProcessBuilder;
+import org.gradle.process.internal.WorkerProcessFactory;
 import org.gradle.util.TreeVisitor;
 
 import java.io.File;
@@ -44,13 +44,13 @@ class DefaultPlayToolProvider implements PlayToolProvider {
     private final FileResolver fileResolver;
     private final CompilerDaemonManager compilerDaemonManager;
     private final PlayPlatform targetPlatform;
-    private Factory<WorkerProcessBuilder> workerProcessBuilderFactory;
+    private WorkerProcessFactory workerProcessBuilderFactory;
     private final Set<File> twirlClasspath;
     private final Set<File> routesClasspath;
     private final Set<File> javaScriptClasspath;
 
     public DefaultPlayToolProvider(FileResolver fileResolver, CompilerDaemonManager compilerDaemonManager,
-                                   Factory<WorkerProcessBuilder> workerProcessBuilderFactory, PlayPlatform targetPlatform,
+                                   WorkerProcessFactory workerProcessBuilderFactory, PlayPlatform targetPlatform,
                                    Set<File> twirlClasspath, Set<File> routesClasspath, Set<File> javaScriptClasspath) {
         this.fileResolver = fileResolver;
         this.compilerDaemonManager = compilerDaemonManager;
@@ -63,6 +63,7 @@ class DefaultPlayToolProvider implements PlayToolProvider {
         PlayMajorVersion.forPlatform(targetPlatform);
     }
 
+    @Override
     public <T extends CompileSpec> Compiler<T> newCompiler(Class<T> spec) {
         if (TwirlCompileSpec.class.isAssignableFrom(spec)) {
             TwirlCompiler twirlCompiler = TwirlCompilerFactory.create(targetPlatform);
@@ -91,10 +92,12 @@ class DefaultPlayToolProvider implements PlayToolProvider {
         return converted;
     }
 
+    @Override
     public boolean isAvailable() {
         return true;
     }
 
+    @Override
     public void explain(TreeVisitor<? super String> visitor) {
     }
 }
